@@ -39,7 +39,7 @@ setGeneric("dose",
            },
            valueClass="numeric")
 
-##' @describeIn dose
+##' @rdname dose
 ##' @example examples/Model-method-dose.R
 setMethod("dose",
           signature=
@@ -147,7 +147,7 @@ setGeneric("prob",
 ## todo: simplify this to always vectorize internally over points -> always
 ## take/return matrix
 
-##' @describeIn prob
+##' @rdname prob
 ##' @example examples/Model-method-prob.R
 setMethod("prob",
           signature=
@@ -383,7 +383,7 @@ setGeneric("gain",
              },
            valueClass="numeric")
 
-##' @describeIn gain
+##' @rdname gain
 ##' @example examples/Model-method-gain.R
 setMethod("gain",
           signature=
@@ -572,20 +572,13 @@ setMethod("update",
             function(object,
                      data,
                      ...){
-              ##Get Pseudo Eff responses (prior) of the model
-              
-              PseudoEff<-object@Eff
-              
-              ##Get the corresponding dose levels for the Pseudo DLE responses from the model
-              PseudoEffdose<- object@Effdose
-              
-              ## Get the initial values of parameters for nu (if it is not fixed)
-              ##OR get the fixed value of nu
-              PseudoNu<- object@nu
-              
               
               ##update the model estimates with data
-              model<- Effloglog(Eff=PseudoEff,Effdose=PseudoEffdose,nu=PseudoNu,data=data)
+              model <- Effloglog(Eff=object@Eff,
+                                 Effdose=object@Effdose,
+                                 nu=object@nu,
+                                 c=object@c,
+                                 data=data)
               
               ##return the updated model
               return(model)
